@@ -18,14 +18,6 @@
 #include "purpose/job.h"
 #include "purpose/pluginbase.h"
 
-// FIXME: For some reason PLUGIN_PHABRICATOR isn't exported from the PhabricatorHelpers lib
-#undef qCDebug
-#define qCDebug(dum) qDebug()
-#undef qCWarning
-#define qCWarning(dum) qWarning()
-#undef qCCritical
-#define qCCritical(dum) qCritical()
-
 class PhabricatorJob : public Purpose::Job
 {
     Q_OBJECT
@@ -37,10 +29,10 @@ public:
 
     void start() override
     {
-        const QString localBaseDir(data().value(QStringLiteral("localBaseDir")).toString());
-        const QUrl sourceFile(data().value(QStringLiteral("urls")).toArray().first().toString());
-        const QString updateDR = data().value(QStringLiteral("updateDR")).toString();
-        const bool doBrowse = data().value(QStringLiteral("doBrowse")).toBool();
+        const QString localBaseDir(data().value(QLatin1String("localBaseDir")).toString());
+        const QUrl sourceFile(data().value(QLatin1String("urls")).toArray().first().toString());
+        const QString updateDR = data().value(QLatin1String("updateDR")).toString();
+        const bool doBrowse = data().value(QLatin1String("doBrowse")).toBool();
 
         const QString baseDir = QUrl(localBaseDir).toLocalFile();
 
@@ -60,11 +52,11 @@ public:
             return;
         }
 
-        m_drTitle = data().value(QStringLiteral("drTitle")).toString();
+        m_drTitle = data().value(QLatin1String("drTitle")).toString();
 
         KJob *job;
         if (!updateDR.isEmpty()) {
-            const QString updateComment = data().value(QStringLiteral("updateComment")).toString();
+            const QString updateComment = data().value(QLatin1String("updateComment")).toString();
             job = new Phabricator::UpdateDiffRev(sourceFile, baseDir, updateDR, updateComment, doBrowse, this);
             connect(job, &KJob::finished, this, &PhabricatorJob::diffUpdated);
         } else {
@@ -112,18 +104,11 @@ public:
     QString m_drTitle;
 };
 
-class Q_DECL_EXPORT PhabricatorPlugin : public Purpose::PluginBase
+class PhabricatorPlugin : public Purpose::PluginBase
 {
     Q_OBJECT
 public:
-    PhabricatorPlugin(QObject *parent, const QList<QVariant> & /*args*/)
-        : PluginBase(parent)
-    {
-    }
-    ~PhabricatorPlugin() override
-    {
-    }
-
+    using PluginBase::PluginBase;
     Purpose::Job *createJob() const override
     {
         return new PhabricatorJob;
